nanodb-driver
-------------

*nanodb-driver* is a driver to interact with
`nanodb server <https://github.com/nano-db/NanoCube>`_


How to install
--------------

You can install PyDrive with regular ``pip`` command.

::

    $ pip install nanodb-driver